@@ -54,6 +54,25 @@ class DeferredCall(object):
         self.result_hook._return.append( r[0] if isinstance(r, list) and len(r) == 1 else r )
         
 class DynamicAx(object):
+    """ Wrapper around an matplotlib axis returned
+        by DynamicFig, which is returned by figure().
+    
+        All calls to the returned axis are delegated to
+        matplotlib with the amendmend that if any such function
+        returs a list with one member, it will just return
+        this member.
+        This caters for the very common use case plot() where
+        x,y are vectors. Assume y2 is an updated data set
+        In this case we can use
+        
+            fig = figure()
+            ax  = fig.add_subplot()
+            lns = ax.plot( x, y, ":" )
+            fig.render() # --> draw graph
+            
+            lns.set_ydata( y2 )
+            fig.render() # --> change graph
+    """
     
     def __init__(self, row : int, col : int ):
         """ Internal object which defers the creation of various graphics to a later point        
@@ -138,6 +157,53 @@ class DynamicFig(object):
             plt.close(self.fig)  # removes shaddow draw in Jupyter
         self.hdisplay.update(self.fig)  
     
+def figure(row_size : int = 5, col_size : int = 4, col_nums : int = 5) -> DynamicFig:
+    """ Generates a dynamic figure using matplot lib.
+        It has the following main functions
+        
+            add_subplot():
+                Used to create a sub plot. No need to provide the customary
+                rows, cols, and total number as this will computed for you.
+                
+                All calls to the returned 'ax' are delegated to
+                matplotlib with the amendmend that if any such function
+                returs a list with one member, it will just return
+                this member.
+                This caters for the very common use case plot() where
+                x,y are vectors. Assume y2 is an updated data set
+                In this case we can use
+                
+                    fig = figure()
+                    ax  = fig.add_subplot()
+                    lns = ax.plot( x, y, ":" )
+                    fig.render() # --> draw graph
+                    
+                    lns.set_ydata( y2 )
+                    fig.render() # --> change graph
+                    
+            render():
+                Draws the figure as it is.
+                Call repeatedly if the underlying graphs are modified
+                as per example above.
+                No further add_subplots() are recommended
+
+        Paraneters 
+        ----------
+            row_size : int, optional
+                Size for a row for matplot lib. Default is 5
+            col_size : int, optional
+                Size for a column for matplot luib. Default is 4
+            col_nums : int, optional
+                How many columns. Default is 5  
+                
+        Returns
+        -------
+            DynamicFig
+                A figure wrapper; see above.
+    """   
+    return DynamicFig( row_size=row_size, col_size=col_size, col_nums=col_nums ) 
+    
+    
 def test():
     import numpy as np
 
